package
module
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Dec 21, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Error(t t, expected, actual error)
func Nil[T any](t t, v *T)
func NotError(t t, err error)
func NotNil[T any](t t, v *T)
func True(t t, expression bool)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.